@@ -35,7 +35,9 @@
 #include <gio/gio.h>
 #include <stdlib.h>
 #include <gtk/gtk.h>
+#ifdef HAVE_VTE
 #include <vte/vte.h>
+#endif
 #include <canberra-gtk.h>
 
 #include "gcm-calibrate-argyll.h"
@@ -50,6 +52,8 @@
 
 #define FIXED_ARGYLL
 
+//#define USE_DOUBLE_DENSITY
+
 static void     gcm_calibrate_argyll_finalize	(GObject     *object);
 
 #define GCM_CALIBRATE_ARGYLL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GCM_TYPE_CALIBRATE_ARGYLL, GcmCalibrateArgyllPrivate))
@@ -170,15 +174,18 @@ gcm_calibrate_argyll_printer_get_patches (GcmCalibrateArgyll *calibrate_argyll)
 	else if (precision == GCM_CALIBRATE_PRECISION_LONG)
 		patches = 360;
 
+#ifdef USE_DOUBLE_DENSITY
 	/* using double density, so we can double the patch count */
 	if (colorimeter_kind == GCM_COLORIMETER_KIND_COLOR_MUNKI ||
 	    colorimeter_kind == GCM_COLORIMETER_KIND_SPECTRO_SCAN) {
 		patches *= 2;
 	}
+#endif
 
 	return patches;
 }
 
+#ifdef HAVE_VTE
 /**
  * gcm_calibrate_argyll_get_colorimeter_image_attach:
  **/
@@ -228,6 +235,7 @@ gcm_calibrate_argyll_get_colorimeter_image_screen (GcmCalibrateArgyll *calibrate
 		return "munki-screen.svg";
 	return NULL;
 }
+#endif
 
 /**
  * gcm_calibrate_argyll_get_display:
@@ -360,7 +368,8 @@ out:
 static gboolean
 gcm_calibrate_argyll_fork_command (GcmCalibrateArgyll *calibrate_argyll, gchar **argv, GError **error)
 {
-	gboolean ret;
+	gboolean ret = FALSE;
+#ifdef HAVE_VTE
 	const gchar *envp[] = { "ARGYLL_NOT_INTERACTIVE", NULL };
 	const gchar *working_directory;
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
@@ -388,6 +397,7 @@ gcm_calibrate_argyll_fork_command (GcmCalibrateArgyll *calibrate_argyll, gchar *
 	/* we're running */
 	priv->state = GCM_CALIBRATE_ARGYLL_STATE_RUNNING;
 out:
+#endif
 	return ret;
 }
 
@@ -484,6 +494,7 @@ gcm_calibrate_argyll_display_neutralise (GcmCalibrateArgyll *calibrate_argyll, G
 		ret = FALSE;
 		goto out;
 	}
+#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -495,6 +506,7 @@ gcm_calibrate_argyll_display_neutralise (GcmCalibrateArgyll *calibrate_argyll, G
 		ret = FALSE;
 		goto out;
 	}
+#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -574,6 +586,7 @@ gcm_calibrate_argyll_display_read_chart (GcmCalibrateArgyll *calibrate_argyll, G
 		ret = FALSE;
 		goto out;
 	}
+#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -585,6 +598,7 @@ gcm_calibrate_argyll_display_read_chart (GcmCalibrateArgyll *calibrate_argyll, G
 		ret = FALSE;
 		goto out;
 	}
+#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -679,6 +693,7 @@ gcm_calibrate_argyll_display_generate_patches (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
+#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -690,6 +705,7 @@ gcm_calibrate_argyll_display_generate_patches (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
+#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -773,6 +789,7 @@ gcm_calibrate_argyll_display_draw_and_measure (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
+#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -784,6 +801,7 @@ gcm_calibrate_argyll_display_draw_and_measure (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
+#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -888,6 +906,7 @@ gcm_calibrate_argyll_display_generate_profile (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
+#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -899,7 +918,7 @@ gcm_calibrate_argyll_display_generate_profile (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
-
+#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -1109,6 +1128,7 @@ gcm_calibrate_argyll_device_measure (GcmCalibrateArgyll *calibrate_argyll, GErro
 		ret = FALSE;
 		goto out;
 	}
+#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -1120,6 +1140,7 @@ gcm_calibrate_argyll_device_measure (GcmCalibrateArgyll *calibrate_argyll, GErro
 		ret = FALSE;
 		goto out;
 	}
+#endif
 out:
 	g_free (filename);
 	g_free (command);
@@ -1232,6 +1253,7 @@ gcm_calibrate_argyll_device_generate_profile (GcmCalibrateArgyll *calibrate_argy
 		ret = FALSE;
 		goto out;
 	}
+#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -1243,6 +1265,7 @@ gcm_calibrate_argyll_device_generate_profile (GcmCalibrateArgyll *calibrate_argy
 		ret = FALSE;
 		goto out;
 	}
+#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -1481,6 +1504,7 @@ gcm_calibrate_argyll_spotread_read_chart (GcmCalibrateArgyll *calibrate_argyll,
 		ret = FALSE;
 		goto out;
 	}
+#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -1492,6 +1516,7 @@ gcm_calibrate_argyll_spotread_read_chart (GcmCalibrateArgyll *calibrate_argyll,
 		ret = FALSE;
 		goto out;
 	}
+#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -1608,11 +1633,13 @@ gcm_calibrate_argyll_display_generate_targets (GcmCalibrateArgyll *calibrate_arg
 	/* target instrument */
 	g_ptr_array_add (array, g_strdup_printf ("-i%s", gcm_calibrate_argyll_get_colorimeter_target (calibrate_argyll)));
 
+#ifdef USE_DOUBLE_DENSITY
 	/* use double density */
 	if (colorimeter_kind == GCM_COLORIMETER_KIND_COLOR_MUNKI ||
 	    colorimeter_kind == GCM_COLORIMETER_KIND_SPECTRO_SCAN) {
 		g_ptr_array_add (array, g_strdup ("-h"));
 	}
+#endif
 
 	/* 8 bit TIFF 300 dpi */
 	g_ptr_array_add (array, g_strdup ("-t300"));
@@ -1641,6 +1668,7 @@ gcm_calibrate_argyll_display_generate_targets (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
+#ifdef HAVE_VTE
 	if (priv->response == GTK_RESPONSE_REJECT) {
 		gchar *vte_text;
 		vte_text = vte_terminal_get_text (VTE_TERMINAL(priv->terminal), NULL, NULL, NULL);
@@ -1652,6 +1680,7 @@ gcm_calibrate_argyll_display_generate_targets (GcmCalibrateArgyll *calibrate_arg
 		ret = FALSE;
 		goto out;
 	}
+#endif
 out:
 	if (array != NULL)
 		g_ptr_array_unref (array);
@@ -2187,6 +2216,7 @@ out:
 	return ret;
 }
 
+#ifdef HAVE_VTE
 /**
  * gcm_calibrate_argyll_exit_cb:
  **/
@@ -2694,7 +2724,9 @@ out:
 		g_string_free (string, TRUE);
 	return ret;
 }
+#endif
 
+#ifdef HAVE_VTE
 /**
  * gcm_calibrate_argyll_selection_func_cb:
  **/
@@ -2745,6 +2777,7 @@ gcm_calibrate_argyll_cursor_moved_cb (VteTerminal *terminal, GcmCalibrateArgyll
 	g_free (output);
 	g_strfreev (split);
 }
+#endif
 
 /**
  * gcm_calibrate_argyll_response_cb:
@@ -2763,7 +2796,9 @@ gcm_calibrate_argyll_response_cb (GtkWidget *widget, GtkResponseType response, G
 		/* send input if waiting */
 		if (priv->state == GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN) {
 			egg_debug ("sending '%s' to argyll", priv->argyllcms_ok);
+#ifdef HAVE_VTE
 			vte_terminal_feed_child (VTE_TERMINAL(priv->terminal), priv->argyllcms_ok, 1);
+#endif
 			gcm_calibrate_dialog_pop (priv->calibrate_dialog);
 			priv->state = GCM_CALIBRATE_ARGYLL_STATE_RUNNING;
 		}
@@ -2783,7 +2818,9 @@ gcm_calibrate_argyll_response_cb (GtkWidget *widget, GtkResponseType response, G
 		/* send input if waiting */
 		if (priv->state == GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN) {
 			egg_debug ("sending 'Q' to argyll");
+#ifdef HAVE_VTE
 			vte_terminal_feed_child (VTE_TERMINAL(priv->terminal), "Q", 1);
+#endif
 			priv->state = GCM_CALIBRATE_ARGYLL_STATE_RUNNING;
 		}
 
@@ -2929,6 +2966,7 @@ gcm_calibrate_argyll_init (GcmCalibrateArgyll *calibrate_argyll)
 	calibrate_argyll->priv->screen = gcm_screen_new ();
 
 	/* add vte widget */
+#ifdef HAVE_VTE
 	calibrate_argyll->priv->terminal = vte_terminal_new ();
 	vte_terminal_set_size (VTE_TERMINAL(calibrate_argyll->priv->terminal), 80, 10);
 	g_signal_connect (calibrate_argyll->priv->terminal, "child-exited",
@@ -2937,6 +2975,7 @@ gcm_calibrate_argyll_init (GcmCalibrateArgyll *calibrate_argyll)
 			  G_CALLBACK (gcm_calibrate_argyll_cursor_moved_cb), calibrate_argyll);
 	gcm_calibrate_dialog_pack_details (calibrate_argyll->priv->calibrate_dialog,
 					   calibrate_argyll->priv->terminal);
+#endif
 }
 
 /**
@@ -2957,6 +2996,16 @@ gcm_calibrate_argyll_finalize (GObject *object)
 		g_main_loop_run (priv->loop);
 	}
 
+#ifdef HAVE_VTE
+	/* we don't care if the VTE widget redraws now */
+	g_signal_handlers_disconnect_by_func (calibrate_argyll->priv->terminal,
+					      G_CALLBACK (gcm_calibrate_argyll_exit_cb),
+					      calibrate_argyll);
+	g_signal_handlers_disconnect_by_func (calibrate_argyll->priv->terminal,
+					      G_CALLBACK (gcm_calibrate_argyll_cursor_moved_cb),
+					      calibrate_argyll);
+#endif
+
 	/* hide */
 	gcm_calibrate_dialog_hide (priv->calibrate_dialog);
 
