@@ -28,7 +28,6 @@
 #include <gio/gio.h>
 #include <locale.h>
 #include <gtk/gtk.h>
-#include <unique/unique.h>
 #include <lcms.h>
 
 #include "egg-debug.h"
@@ -233,8 +232,8 @@ gcm_picker_xyz_notify_cb (GcmCalibrate *calibrate_, GParamSpec *pspec, gpointer
 static void
 gcm_picker_close_cb (GtkWidget *widget, gpointer data)
 {
-	GMainLoop *loop = (GMainLoop *) data;
-	g_main_loop_quit (loop);
+	GtkApplication *application = (GtkApplication *) data;
+	gtk_application_quit (application);
 }
 
 /**
@@ -297,20 +296,6 @@ gcm_picker_colorimeter_changed_cb (GcmColorimeter *colorimeter, gpointer user_da
 	gcm_picker_colorimeter_setup_ui (colorimeter);
 }
 
-/**
- * gcm_picker_message_received_cb
- **/
-static UniqueResponse
-gcm_picker_message_received_cb (UniqueApp *app, UniqueCommand command, UniqueMessageData *message_data, guint time_ms, gpointer data)
-{
-	GtkWindow *window;
-	if (command == UNIQUE_ACTIVATE) {
-		window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_picker"));
-		gtk_window_present (window);
-	}
-	return UNIQUE_RESPONSE_OK;
-}
-
 /**
  * gcm_window_set_parent_xid:
  **/
@@ -485,10 +470,9 @@ main (int argc, char *argv[])
 	GOptionContext *context;
 	guint retval = 0;
 	GError *error = NULL;
-	GMainLoop *loop;
+	GtkApplication *application;
 	GtkWidget *main_window;
 	GtkWidget *widget;
-	UniqueApp *unique_app;
 	guint xid = 0;
 	GcmColorimeter *colorimeter = NULL;
 
@@ -522,19 +506,8 @@ main (int argc, char *argv[])
 	g_option_context_parse (context, &argc, &argv, NULL);
 	g_option_context_free (context);
 
-	/* block in a loop */
-	loop = g_main_loop_new (NULL, FALSE);
-
-
-	/* are we already activated? */
-	unique_app = unique_app_new ("org.gnome.ColorManager.Picker", NULL);
-	if (unique_app_is_running (unique_app)) {
-		egg_debug ("You have another instance running. This program will now close");
-		unique_app_send_message (unique_app, UNIQUE_ACTIVATE, NULL);
-		goto out;
-	}
-	g_signal_connect (unique_app, "message-received",
-			  G_CALLBACK (gcm_picker_message_received_cb), NULL);
+	/* ensure single instance */
+	application = gtk_application_new ("org.gnome.ColorManager.Picker", &argc, &argv);
 
 	/* get UI */
 	builder = gtk_builder_new ();
@@ -546,13 +519,14 @@ main (int argc, char *argv[])
 	}
 
 	main_window = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_picker"));
+	gtk_application_add_window (application, GTK_WINDOW (main_window));
 	gtk_window_set_icon_name (GTK_WINDOW (main_window), GCM_STOCK_ICON);
 	g_signal_connect (main_window, "delete_event",
-			  G_CALLBACK (gcm_picker_delete_event_cb), loop);
+			  G_CALLBACK (gcm_picker_delete_event_cb), application);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
 	g_signal_connect (widget, "clicked",
-			  G_CALLBACK (gcm_picker_close_cb), loop);
+			  G_CALLBACK (gcm_picker_close_cb), application);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_help"));
 	g_signal_connect (widget, "clicked",
@@ -621,10 +595,10 @@ main (int argc, char *argv[])
 
 	/* wait */
 	gtk_widget_show (main_window);
-	g_main_loop_run (loop);
+	gtk_application_run (application);
 
 out:
-	g_object_unref (unique_app);
+	g_object_unref (application);
 	if (profile_store != NULL)
 		g_object_unref (profile_store);
 	if (colorimeter != NULL)
@@ -633,7 +607,6 @@ out:
 		g_object_unref (calibrate);
 	if (builder != NULL)
 		g_object_unref (builder);
-	g_main_loop_unref (loop);
 	return retval;
 }
 
