@@ -24,8 +24,9 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <locale.h>
+#ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
-
+#endif
 #include "egg-debug.h"
 
 #include "gcm-client.h"
@@ -67,6 +68,7 @@ gcm_session_check_idle_cb (gpointer user_data)
 	return TRUE;
 }
 
+#ifdef HAVE_LIBNOTIFY
 /**
  * gcm_session_notify_cb:
  **/
@@ -88,6 +90,7 @@ gcm_session_notify_cb (NotifyNotification *notification, gchar *action, gpointer
 		}
 	}
 }
+#endif
 
 /**
  * gcm_session_notify_recalibrate:
@@ -340,6 +343,10 @@ gcm_session_get_profiles_for_file (const gchar *filename, GError **error)
 		}
 	}
 
+	/* nothing found, so set error */
+	if (array == NULL)
+		g_set_error_literal (error, 1, 0, "No profiles were found.");
+
 	/* unref list of devices */
 	g_ptr_array_unref (array_devices);
 out:
@@ -400,6 +407,10 @@ gcm_session_get_profiles_for_device (const gchar *device_id_with_prefix, GError
 		}
 	}
 
+	/* nothing found, so set error */
+	if (array == NULL)
+		g_set_error_literal (error, 1, 0, "No profiles were found.");
+
 	/* unref list of devices */
 	g_ptr_array_unref (array_devices);
 	return array;
@@ -514,7 +525,7 @@ gcm_session_handle_method_call (GDBusConnection *connection_, const gchar *sende
 		g_variant_get (parameters, "(ss)", &filename, &hints);
 
 		/* get array of profile filenames */
-		array = gcm_session_get_profiles_for_file (device_id, &error);
+		array = gcm_session_get_profiles_for_file (filename, &error);
 		if (array == NULL) {
 			g_dbus_method_invocation_return_dbus_error (invocation,
 								    "org.gnome.ColorManager.Failed",
